@@ -73,6 +73,12 @@ from qurator.eynollah.eynollah import Eynollah
     is_flag=True,
     help="if this parameter set to true, this tool will try to return all elements of layout.",
 )
+@click.option(
+    "--tables/--no-tables",
+    "-tab/-notab",
+    is_flag=True,
+    help="if this parameter set to true, this tool will try to detect tables.",
+)
 @click.option(
     "--input_binary/--input-RGB",
     "-ib/-irgb",
@@ -109,6 +115,7 @@ def main(
     allow_enhancement,
     curved_line,
     full_layout,
+    tables,
     input_binary,
     allow_scaling,
     headers_off,
@@ -117,11 +124,11 @@ def main(
     if log_level:
         setOverrideLogLevel(log_level)
     initLogging()
-    if not enable_plotting and (save_layout or save_deskewed or save_all or save_images):
-        print("Error: You used one of -sl, -sd, -sa or -si but did not enable plotting with -ep")
+    if not enable_plotting and (save_layout or save_deskewed or save_all or save_images or allow_enhancement):
+        print("Error: You used one of -sl, -sd, -sa, -si or -ae but did not enable plotting with -ep")
         sys.exit(1)
-    elif enable_plotting and not (save_layout or save_deskewed or save_all or save_images):
-        print("Error: You used -ep to enable plotting but set none of -sl, -sd, -sa or -si")
+    elif enable_plotting and not (save_layout or save_deskewed or save_all or save_images or allow_enhancement):
+        print("Error: You used -ep to enable plotting but set none of -sl, -sd, -sa, -si or -ae")
         sys.exit(1)
     eynollah = Eynollah(
         image_filename=image,
@@ -135,6 +142,7 @@ def main(
         allow_enhancement=allow_enhancement,
         curved_line=curved_line,
         full_layout=full_layout,
+        tables=tables,
         input_binary=input_binary,
         allow_scaling=allow_scaling,
         headers_off=headers_off,
